# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["URLShortenerSettingsParam"]


class URLShortenerSettingsParam(TypedDict, total=False):
    """
    The URL shortener feature allows automatic replacement of URLs that were generated using
    a public URL shortener service. Some examples include bit.do, bit.ly, goo.gl, ht.ly,
    is.gd, ow.ly, rebrand.ly, t.co, tiny.cc, and tinyurl.com. Such URLs are replaced with
    with links generated by Telnyx. The use of custom links can improve branding and message
    deliverability.

    To disable this feature, set the object field to `null`.
    """

    domain: Required[str]
    """One of the domains provided by the Telnyx URL shortener service."""

    prefix: str
    """
    Optional prefix that can be used to identify your brand, and will appear in the
    Telnyx generated URLs after the domain name.
    """

    replace_blacklist_only: bool
    """
    Use the link replacement tool only for links that are specifically blacklisted
    by Telnyx.
    """

    send_webhooks: bool
    """Receive webhooks for when your replaced links are clicked.

    Webhooks are sent to the webhooks on the messaging profile.
    """
