# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .call_enqueued import CallEnqueued

__all__ = ["CallEnqueuedWebhookEvent"]


class CallEnqueuedWebhookEvent(BaseModel):
    data: Optional[CallEnqueued] = None
