# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["Vertical"]

Vertical: TypeAlias = Literal[
    "REAL_ESTATE",
    "HEALTHCARE",
    "ENERGY",
    "ENTERTAINMENT",
    "RETAIL",
    "AGRICULTURE",
    "INSURANCE",
    "EDUCATION",
    "HOSPITALITY",
    "FINANCIAL",
    "GAMBLING",
    "CONSTRUCTION",
    "NGO",
    "MANUFACTURING",
    "GOVERNMENT",
    "TECHNOLOGY",
    "COMMUNICATION",
]
