# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.ai import (
    MissionData,
    MissionCreateResponse,
    MissionRetrieveResponse,
    MissionListEventsResponse,
    MissionUpdateMissionResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMissions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        mission = client.ai.missions.create(
            name="name",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.create(
            name="name",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionCreateResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        mission = client.ai.missions.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        mission = client.ai.missions.list()
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.list(
            page_number=1,
            page_size=1,
        )
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_clone_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.clone_mission(
            "mission_id",
        )
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_clone_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.clone_mission(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_clone_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.clone_mission(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(object, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_clone_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.clone_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert mission is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.delete_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_events(self, client: Telnyx) -> None:
        mission = client.ai.missions.list_events()
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_events_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.list_events(
            page_number=1,
            page_size=1,
            type="type",
        )
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_events(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_events(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_mission_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
            name="name",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.update_mission(
                mission_id="",
            )


class TestAsyncMissions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.create(
            name="name",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.create(
            name="name",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionCreateResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list()
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list(
            page_number=1,
            page_size=1,
        )
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_clone_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.clone_mission(
            "mission_id",
        )
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_clone_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.clone_mission(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_clone_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.clone_mission(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(object, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_clone_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.clone_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert mission is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.delete_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_events(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list_events()
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_events_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list_events(
            page_number=1,
            page_size=1,
            type="type",
        )
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_events(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_events(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_mission_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
            name="name",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.update_mission(
                mission_id="",
            )
