# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["InexplicitNumberOrderListParams"]


class InexplicitNumberOrderListParams(TypedDict, total=False):
    page_number: int
    """The page number to load"""

    page_size: int
    """The size of the page"""
